CPCCA
=====

.. currentmodule:: xeofs.cross

.. autoclass:: CPCCA
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CPCCA.__init__
      ~CPCCA.components
      ~CPCCA.compute
      ~CPCCA.correlation_coefficients_X
      ~CPCCA.correlation_coefficients_Y
      ~CPCCA.cross_correlation_coefficients
      ~CPCCA.deserialize
      ~CPCCA.fit
      ~CPCCA.fraction_variance_X_explained_by_X
      ~CPCCA.fraction_variance_Y_explained_by_X
      ~CPCCA.fraction_variance_Y_explained_by_Y
      ~CPCCA.get_params
      ~CPCCA.get_serialization_attrs
      ~CPCCA.heterogeneous_patterns
      ~CPCCA.homogeneous_patterns
      ~CPCCA.inverse_transform
      ~CPCCA.load
      ~CPCCA.predict
      ~CPCCA.save
      ~CPCCA.scores
      ~CPCCA.serialize
      ~CPCCA.squared_covariance_fraction
      ~CPCCA.transform
   
   

   
   
   